@@ -16,5 +16,5 @@ VRC <- function(tofactor = 0, keepblank = 0, sep = "\t") {
     nast <- c("NA", "")
     if((identical(keepblank, 1) | identical(keepblank, TRUE)) & asfa == FALSE)
         nast <- "NA"
-    utils::read.table("clipboard", header = TRUE, row.names = 1, blank.lines.skip = FALSE, sep = sep, na.strings = nast, stringsAsFactors = asfa)
+    utils::read.table("clipboard", header = TRUE, row.names = 1, blank.lines.skip = FALSE, sep = sep, na.strings = nast, stringsAsFactors = asfa, quote = "")
 }
